@@ -9,6 +9,9 @@ import (
 	"runtime"
 	"strings"
 
+	"net/http"
+	_ "net/http/pprof" // load profiling http handler
+
 	log "github.com/sirupsen/logrus"
 
 	"github.com/dundee/gdu/v5/build"
@@ -51,6 +54,8 @@ type Flags struct {
 	NoProgress        bool
 	NoCross           bool
 	NoHidden          bool
+	Profiling         bool
+	EnableGC          bool
 	Summarize         bool
 }
 
@@ -172,6 +177,7 @@ func (a *App) createUI() (UI, error) {
 			output,
 			!a.Flags.NoColor && a.Istty,
 			!a.Flags.NoProgress && a.Istty,
+			a.Flags.EnableGC,
 		)
 		return ui, nil
 	}
@@ -183,6 +189,7 @@ func (a *App) createUI() (UI, error) {
 			!a.Flags.NoProgress && a.Istty,
 			a.Flags.ShowApparentSize,
 			a.Flags.Summarize,
+			a.Flags.EnableGC,
 		)
 	} else {
 		ui = tui.CreateUI(
@@ -191,6 +198,7 @@ func (a *App) createUI() (UI, error) {
 			os.Stdout,
 			!a.Flags.NoColor,
 			a.Flags.ShowApparentSize,
+			a.Flags.EnableGC,
 		)
 
 		if !a.Flags.NoColor {
@@ -215,6 +223,12 @@ func (a *App) setNoCross(path string) error {
 }
 
 func (a *App) runAction(ui UI, path string) error {
+	if a.Flags.Profiling {
+		go func() {
+			log.Println(http.ListenAndServe("localhost:6060", nil))
+		}()
+	}
+
 	if a.Flags.ShowDisks {
 		if err := ui.ListDevices(a.Getter); err != nil {
 			return fmt.Errorf("loading mount points: %w", err)
