@@ -1,3 +1,4 @@
+//go:build linux
 // +build linux
 
 package tui
@@ -17,7 +18,7 @@ func TestShowDevicesWithError(t *testing.T) {
 
 	getter := device.LinuxDevicesInfoGetter{MountsPath: "/xyzxyz"}
 
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false)
 	err := ui.ListDevices(getter)
 
 	assert.Contains(t, err.Error(), "no such file")
